
import geoip2.models
from odoo import http
from odoo.http import request
from odoo.tools import lazy_property
from odoo.addons.saas_worker.const import TEST


class GeoIP(http.GeoIP):
    """Extend GeoIP to allow force user geolocation (internal user only)."""

    @lazy_property
    def _city_record(self):
        if request and request.session.get('localization_force_country'):
            country_code = request.session["localization_force_country"]
            return geoip2.models.City({'country': {'iso_code': country_code}})
        return super()._city_record

    @lazy_property
    def _country_record(self):
        if request and request.session.get('localization_force_country'):
            country_code = request.session["localization_force_country"]
            return geoip2.models.Country({'country': {'iso_code': country_code}})
        return super()._country_record

http.GeoIP = GeoIP


class Localization(http.Controller):

    @http.route('/localization', auth='public', website=True, sitemap=False)
    def odoo_localization(self, country=False, redirect='/', **kwargs):
        if request.env.user.has_group('base.group_user') or TEST:
            if country:
                request.session['localization_force_country'] = country
            else:
                request.session.pop('localization_force_country', None)
            request.session.is_dirty = True
        if redirect:
            return request.redirect(redirect)
        else:
            return request.make_response(request.session['localization_force_country'])
